@@ -130,7 +130,7 @@ def create_edit_issue(issue=None, text=None):
     return {'title': title, 'body': body}
 
 
-def create_comment(issue):
+def create_comment(issue=None, text=None):
     inp = """
 # Please enter a comment.
 # Lines starting with `#` will be ignored.
@@ -140,7 +140,11 @@ def create_comment(issue):
 #     votes:  %(votes)s
 #     state:  %(state)s
 #   created:  %(created_at)s""" % issue
-    out = edit_text(inp)
+    if text:
+        # \n on the command-line becomes \\n; undoing this:
+        out = text.replace("\\n", "\n")
+    else:
+        out = edit_text(inp)
     if not out:
         raise Exception("can not submit an empty comment")
     lines = out.splitlines()
@@ -153,7 +157,7 @@ class Commands(object):
     def __init__(self, user, repo):
         self.user = user
         self.repo = repo
-        self.url_template = "http://github.com/api/v2/json/issues/%s/%s/%s"
+        self.url_template = "https://github.com/api/v2/json/issues/%s/%s/%s"
 
     def search(self, search_term=None, state='open', verbose=False, **kwargs):
         if not search_term:
@@ -174,9 +178,10 @@ class Commands(object):
             printer.write("\n".join(lines))
         printer.close()
 
-    def list(self, state='open', verbose=False, webbrowser=False, **kwargs):
+    def list(self, state='open', verbose=False, webbrowser=False, 
+            created_by=False, **kwargs):
         if webbrowser:
-            issues_url_template = "http://github.com/%s/%s/issues/%s"
+            issues_url_template = "https://github.com/%s/%s/issues/%s"
             if state == "closed":
                 issues_url = issues_url_template % (self.user, self.repo,
                     state)
@@ -201,8 +206,9 @@ class Commands(object):
             issues = get_key(result, 'issues')
             if issues:
                 for issue in issues:
-                    lines = format_issue(issue, verbose)
-                    printer.write("\n".join(lines))
+                    if created_by == False or created_by == issue.get('user'):
+                        lines = format_issue(issue, verbose)
+                        printer.write("\n".join(lines))
             else:
                 printer.write("no %s issues available" % st)
             if not st == states[-1]:
@@ -212,7 +218,7 @@ class Commands(object):
     def show(self, number=None, verbose=False, webbrowser=False, **kwargs):
         validate_number(number, example="%s show 1" % get_prog())
         if webbrowser:
-            issue_url_template = "http://github.com/%s/%s/issues/%s/find"
+            issue_url_template = "https://github.com/%s/%s/issues/%s"
             issue_url = issue_url_template % (self.user, self.repo, number)
             try:
                 browser.open(issue_url)
@@ -290,10 +296,10 @@ class Commands(object):
         else:
             print "no labels found for issue #%s" % number
 
-    def comment(self, number=None, **kwargs):
+    def comment(self, number=None, message=None, **kwargs):
         validate_number(number, example="%s comment 1" % get_prog())
         gh_issue = self.__get_issue(number)
-        comment = create_comment(gh_issue)
+        comment = create_comment(issue=gh_issue, text=message)
         post_data = {'comment': comment}
         result = self.__submit('comment', number, data=post_data)
         returned_comment = get_key(result, 'comment')
@@ -329,6 +335,8 @@ Examples:
 %prog -v                              same as: %prog list -v
 %prog [-s o|c] -w                     show issues' GitHub page in web browser
                                     (default: open)
+%prog list -u <github_user>           show issues created by specified user
+
 %prog show <nr>                       show issue <nr>
 %prog show <nr> -v                    same as above, but with comments
 %prog <nr>                            same as: %prog show <nr>
@@ -348,6 +356,9 @@ Examples:
 %prog s <term> -s closed              only search in closed issues
 %prog comment (m) <nr>                create a comment for issue <nr>
                                     (with $EDITOR)
+%prog comment (m) <nr> -m <msg>       create a comment for issue <nr>
+                                    with <msg> content. (optionally use \\n
+                                    for new lines)
 %prog -r <user>/<repo>                specify a repository (can be used for
                                     all commands)
 %prog -r <repo>                       specify a repository (gets user from
@@ -365,9 +376,11 @@ command-line interface to GitHub's Issues API (v2)"""
         default='open', help="specify state (only for list and search "\
         "(except `all`) commands) choices are: open (o), closed (c), all "\
         "(a) [default: open]")
+    parser.add_option("-u", "--user", action="store", dest="created_by", default=False,\
+        help="issues created by <github_username> [default: all]")
     parser.add_option("-m", "--message", action="store", dest="message",
-      default=None, help="message content for opening an issue without "\
-        "using the editor")
+      default=None, help="message content for opening or commenting on an "\
+        "issue without using the editor")
     parser.add_option("-r", "--repo", "--repository", action="store",
         dest="repo", help="specify a repository (format: "\
             "`user/repo` or just `repo` (latter will get the user from the "\
