@@ -56,6 +56,13 @@ def get_remote_info():
             if result:
                 return result.groups()
             else:
+                # Whilst repos are usually configured with a postfix of ".git"
+                # this is by convention only. Github happily handles requests
+                # without the postfix.
+                pattern = re.compile(r'([^:/]+)/([^/]+)')
+                result = pattern.search(line)
+                if result:
+                    return result.groups()
                 raise Exception("invalid user and repo name")
         elif stderr:
             for line in stderr.splitlines():
@@ -97,18 +104,23 @@ def get_remote_info_from_option(repository):
 
 
 def get_config():
-    required_keys = ["user", "token"]
+    required_keys = {
+        'user': 'GITHUB_USER',
+        'token': 'GITHUB_TOKEN'
+    }
     config = {}
-    for key in required_keys:
-        command = "git config --global github.%s" % key
-        stdout, stderr = Popen(command, shell=True, stdin=PIPE, stdout=PIPE,
-            stderr=PIPE).communicate()
-        if stderr:
-            for line in stderr.splitlines():
-                print line
-            sys.exit(1)
-        if stdout:
+    for key, env_key in required_keys.items():
+        value = os.environ.get(env_key)
+        if not value:
+            command = "git config --global github.%s" % key
+            stdout, stderr = Popen(command, shell=True, stdin=PIPE, stdout=PIPE,
+                stderr=PIPE).communicate()
+            if stderr:
+                for line in stderr.splitlines():
+                    print line
+                sys.exit(1)
             value = stdout.strip()
+        if value:
             config[key] = value
         else:
             alt_help_names = {'user': 'username'}
@@ -117,8 +129,11 @@ def get_config():
                 "git config" % key
             print "please add it to the global git config by doing this:"
             print
-            print "git config --global github.%s <your GitHub %s>" % (key,
+            print "    git config --global github.%s <your GitHub %s>" % (key,
                 help_name)
+            print
+            print "or by specifying environment variables GITHUB_USER and "\
+				"GITHUB_TOKEN"
             sys.exit(1)
     return config
 
@@ -189,8 +204,9 @@ class Pager(object):
             try:
                 self.proc.wait()
             except KeyboardInterrupt:
-                # TODO: should kill the self.proc here gracefully
-                sys.exit(0) # close silently no matter what
+                sys.proc.kill()
+                sys.exit(1)
+
 
 
 def wrap_text(text, width=79):
